Test if two image files are equivalent
expect_equivalent_images(
current,
target,
tol = getOption("tinysnapshot_tol", default = 0),
metric = getOption("tinysnapshot_metric", default = "AE"),
fuzz = getOption("tinysnapshot_fuzz", default = 0),
style = getOption("tinysnapshot_plot_diff_style", default = c("old", "new", "diff")),
review = getOption("tinysnapshot_plot_review", default = TRUE),
diffpath = NULL
)A tinytest object. A tinytest object is a logical with attributes holding information about the test that was run
path to an image file
path to an image file
distance estimates larger than this threshold will trigger a test failure. Scale depends on the metric argument. With the default metric="AE" (absolute error), the tolerance corresponds roughly to the number of pixels of difference between the plot and the reference image.
string with a metric from magick::metric_types() such as "AE" or "phash".
relative color distance between 0 and 100 to be considered similar.
A character vector to control the panels of the diff image saved to file. The order and number of entries controls the side-by-side panels. Allowable values are: "old", "new", "diff".
logical. TRUE if a a diff plot should be saved to file for review when the expectation fails.
path where to save an image which shows the differences between current and target. NULL means that the diff image is not saved.